Game

Struct Game 

pub struct Game {
    pub max_depth: Depth,
    pub board: Board,
    pub move_time: MoveTime,
    pub move_number: MoveNumber,
    pub node_count: u64,
    pub game_history: History,
    /* private fields */
}
A chess game

Fields

max_depth: Depthboard: Boardmove_time: MoveTimemove_number: MoveNumbernode_count: u64game_history: History

Implementations

Source

impl Game

pub fn new(fen: String, max_depth: Depth, move_time: MoveTime) -> Self

Create a game giving a position as a FEN, max depth and a move time.

pub fn set_timer(&mut self) -> JoinHandle<()>

Set a timer to stop playing after the move time has elapsed.

pub fn find_move(&mut self) -> Option<Move>

Find the best move